CombinedRepresentation
======================

.. currentmodule:: pykeen.nn.representation

.. autoclass:: CombinedRepresentation
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~CombinedRepresentation.combine

   .. rubric:: Methods Documentation

   .. automethod:: combine
